;------------------------------------------------------------------------------
; CAD Concepts
;  
; COPY CLIPBOARD INSUNITS
;
; Copyright (C) 2015 CAD Concepts Limited.
; 
; This program is free software: you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation, either version 3 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; For a copy of the GNU General Public License, see
; <http://www.gnu.org/licenses/>. 
;------------------------------------------------------------------------------
;
; File        : CopyClipboardInsunits.lsp
; Author      : Jason Bourhill
; Web					: http://www.cadconcepts.co.nz
; Date        : 28/01/2015
; CAD Ver(s)	: Bricscad V13.1.15 and above
;------------------------------------------------------------------------------
 
; PURPOSE:
; Starting with V13.1.15, BricsCAD respects the value of INSUNITS when copying
; between drawings (AutoCAD ignores) using COPYCLIP, and COPYBASE). This can
; give unexpected results for users that use different units between Modelspace
; and Paperspace.
;
; When copying from paperspace these routines set INSUNITS = 0 (No units) prior
; to copying to the Clipboard to avoids scaling being applied when copying and
; pasting. ; INSUNITS are not changed if copying from Modelspace
;
; COMMANDS
;
; COPYCLIP-NOUNITS
; COPYBASE-NOUNITS
;
; NOTES:
; To work these functions require that INSUNITSDEFSOURCE = 0, or that
; INSUNITSDEFSOURCE and INSUNITSDEFTARGET are set to the same units.
; When INSUNITS = 0 BricsCAD will instead use the values of INSUNITSDEFSOURCE
; and INSUNITSDEFSOURCE if they have been set.
;
; May give unexpected results if copying and pasting to different spaces.
;
;------------------------------------------------------------------------------

(defun C:CopyClip-NoUnits ( / *ERROR* sset)
	;Error handler
	 (defun *ERROR* (error_msg)
		 (if error_msg (princ (strcat "\n" error_msg ))) ; Print error message if given
		 (acet-sysvar-restore) ; reset any environment variables to their previous state
		 (prin1)
	 )
	 (princ "\nSelect entities to copy to the clipboard: ") ; prompt user
	 (setq sset (ssget)) ;  Create a selection set, only accepting Multi Leader objects
		(if sset ; if a valid selection set is created
			(progn ; THEN
				(if (> 2 (getvar 'CVPORT)) ; save environment variables based on which space we're in
						(acet-sysvar-set '("CMDECHO" 0 "INSUNITS" 0)) ; Paperspace
						(acet-sysvar-set '("CMDECHO" 0 )) ; Modelspace
				)
				(command "._COPYCLIP" sset "") ; copy our objects to the clipboard, in the process they will be converted.
				(princ (strcat "\n" (itoa (sslength sset)) " entities copied to clipboard")) ; prompt user as to what has happended.
				(acet-sysvar-restore) ; reset any environment variables to their previous state
			) ; end progn
			(princ "\nNo entities selected") ; ELSE prompt user
		) ; end if
 (prin1) ; make a quiet exit
) ; end CopyClip-NoUnits
 
 
(defun C:CopyBase-NoUnits ( / *ERROR* bp sset)
	;Error handler
	 (defun *ERROR* (error_msg)
		 (if error_msg (princ (strcat "\n" error_msg ))) ; Print error message if given
		 (acet-sysvar-restore) ; reset any environment variables to their previous state
		 (prin1)
	 )
	 (initget 1) ; don't allow null entry
	 (setq bp (getpoint "\nSelect base point: "))
	 (if bp
	 	(progn
			 (princ "\nSelect entities to copy to the clipboard: ") ; prompt user
			 (setq sset (ssget)) ;  Create a selection set, only accepting Multi Leader objects
				(if sset ; if a valid selection set is created
					(progn ; THEN
						(if (> 2 (getvar 'CVPORT)) ; save environment variables based on which space we're in
								(acet-sysvar-set '("CMDECHO" 0 "INSUNITS" 0)) ; Paperspace
								(acet-sysvar-set '("CMDECHO" 0 )) ; Modelspace
						)
						(command "._COPYBASE" bp sset "") ; copy our objects to the clipboard, in the process they will be converted.
						(princ (strcat "\n" (itoa (sslength sset)) " entities copied to clipboard")) ; prompt user as to what has happended.
						(acet-sysvar-restore) ; reset any environment variables to their previous state
					) ; end progn
					(princ "\nNo entities selected") ; ELSE prompt user
				) ; end if
		) ; end progn
		(princ "\nNo point selected") ; ELSE prompt user
	 ); end if 	
 (prin1) ; make a quiet exit
) ; end CopyBase-NoUnits 

(princ "\nClipboard Copy with No Units Loaded type COPYCLIP-NOUNITS, or COPYBASE-NOUNITS to run") ; Inform user of commands
(prin1) ; make a quiet exit